---
name: "mrcal-show-geometry"
section: "1"
platform: "linux"
package: "mrcal"
version: "2.4.1-4+b2"
release: "Debian 13 (Trixie)"
platforms: ["linux"]
url: "https://new.carta.tech/mrcal-show-geometry"
---

# mrcal-show-geometry(1)

Displays the calibration-time geometry: the cameras and the observed objects

## NAME

mrcal-show-geometry - Displays the calibration-time geometry: the cameras and the observed objects

## SYNOPSIS

```
  $ mrcal-show-geometry *.cameramodel
  ... a plot pops up showing the camera arrangement
```

## DESCRIPTION

This tool visualizes the relative geometry between several cameras and the calibration objects they observed when computing the calibration.

## OPTIONS

### POSITIONAL ARGUMENTS

```
  models                Camera models to visualize. Any N cameras can be given
```

### OPTIONAL ARGUMENTS

```
  -h, --help            show this help message and exit
  --axis-scale AXIS_SCALE
                        Scale for the camera axes. By default a reasonable
                        default is chosen (see mrcal.show_geometry() for the
                        logic)
  --title TITLE         Title string for the plot
  --hardcopy HARDCOPY   Write the output to disk, instead of making an
                        interactive plot. The output filename is given in the
                        option
  --terminal TERMINAL   The gnuplotlib terminal. The default is almost always
                        right, so most people don't need this option
  --show-calobjects     If given, draw the calibration object observations
                        from the FIRST given camera model that contains the
                        optimization_inputs. Unlike --show-calobjects-
                        thiscamera, this option displays the calibration
                        objects observed by ALL cameras at calibration time.
                        Exclusive with --show-calobjects-thiscamera
  --show-calobjects-thiscamera
                        If given, draw the calibration object observations
                        from the FIRST given camera model that contains the
                        optimization_inputs. Unlike --show-calobjects, this
                        option displays the calibration objects observed ONLY
                        by the FIRST camera at calibration time. Exclusive
                        with --show-calobjects
  --show-points         If given, draw the point observations from the FIRST
                        given camera model that contains the
                        optimization_inputs. Unlike --show-points-thiscamera,
                        this option displays the points observed by ALL
                        cameras at calibration time. Exclusive with --show-
                        points-thiscamera
  --show-points-thiscamera
                        If given, draw the point observations from the FIRST
                        given camera model that contains the
                        optimization_inputs. Unlike --show-points, this option
                        displays the calibration objects observed ONLY by the
                        FIRST camera at calibration time. Exclusive with
                        --show-points
  --transforms TRANSFORMS
                        Optional transforms.txt. This is a legacy file
                        representing an extra transformation for each camera
                        pair. If you need this, you know what it is
  --set SET             Extra 'set' directives to pass to gnuplotlib. May be
                        given multiple times
  --unset UNSET         Extra 'unset' directives to pass to gnuplotlib. May be
                        given multiple times
```

## REPOSITORY

\<https://www.github.com/dkogan/mrcal\>

## AUTHOR

Dima Kogan, `"<dima@secretsauce.net>"`

## LICENSE AND COPYRIGHT

Copyright (c) 2017-2023 California Institute of Technology ("Caltech"). U.S. Government sponsorship acknowledged. All rights reserved.

Licensed under the Apache License, Version 2.0 (the "License"); You may obtain a copy of the License at

```
    http://www.apache.org/licenses/LICENSE-2.0
```
